# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/workflow_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'fsai_grpc_api/protos/workflow_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xb6\x01\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x0fWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Q\n\x10WorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"6\n\x17QueueMissionScanRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Y\n\x18QueueMissionScanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"6\n\x17ListMissionScansRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Y\n\x18ListMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x03(\x0b\x32\t.Workflow2\xdc\x01\n\x0bWorkflowApi\x12;\n\x14\x46indOrCreateWorkflow\x12\x10.WorkflowRequest\x1a\x11.WorkflowResponse\x12G\n\x10QueueMissionScan\x12\x18.QueueMissionScanRequest\x1a\x19.QueueMissionScanResponse\x12G\n\x10ListMissionScans\x12\x18.ListMissionScansRequest\x1a\x19.ListMissionScansResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_WORKFLOW = _descriptor.Descriptor(
  name='Workflow',
  full_name='Workflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Workflow.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='Workflow.mission_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Workflow.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Workflow.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Workflow.status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Workflow.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Workflow.updated_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=293,
)


_WORKFLOWREQUEST = _descriptor.Descriptor(
  name='WorkflowRequest',
  full_name='WorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='WorkflowRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=341,
)


_WORKFLOWRESPONSE = _descriptor.Descriptor(
  name='WorkflowResponse',
  full_name='WorkflowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='WorkflowResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='WorkflowResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=424,
)


_QUEUEMISSIONSCANREQUEST = _descriptor.Descriptor(
  name='QueueMissionScanRequest',
  full_name='QueueMissionScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionScanRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=480,
)


_QUEUEMISSIONSCANRESPONSE = _descriptor.Descriptor(
  name='QueueMissionScanResponse',
  full_name='QueueMissionScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueueMissionScanResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionScanResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=571,
)


_LISTMISSIONSCANSREQUEST = _descriptor.Descriptor(
  name='ListMissionScansRequest',
  full_name='ListMissionScansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListMissionScansRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=627,
)


_LISTMISSIONSCANSRESPONSE = _descriptor.Descriptor(
  name='ListMissionScansResponse',
  full_name='ListMissionScansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionScansResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListMissionScansResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=718,
)

_WORKFLOW.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOWREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_WORKFLOWRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_WORKFLOWRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONSCANREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONSCANRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUEUEMISSIONSCANRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTMISSIONSCANSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTMISSIONSCANSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONSCANSRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
DESCRIPTOR.message_types_by_name['Workflow'] = _WORKFLOW
DESCRIPTOR.message_types_by_name['WorkflowRequest'] = _WORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['WorkflowResponse'] = _WORKFLOWRESPONSE
DESCRIPTOR.message_types_by_name['QueueMissionScanRequest'] = _QUEUEMISSIONSCANREQUEST
DESCRIPTOR.message_types_by_name['QueueMissionScanResponse'] = _QUEUEMISSIONSCANRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionScansRequest'] = _LISTMISSIONSCANSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionScansResponse'] = _LISTMISSIONSCANSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Workflow = _reflection.GeneratedProtocolMessageType('Workflow', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOW,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:Workflow)
  })
_sym_db.RegisterMessage(Workflow)

WorkflowRequest = _reflection.GeneratedProtocolMessageType('WorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowRequest)
  })
_sym_db.RegisterMessage(WorkflowRequest)

WorkflowResponse = _reflection.GeneratedProtocolMessageType('WorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowResponse)
  })
_sym_db.RegisterMessage(WorkflowResponse)

QueueMissionScanRequest = _reflection.GeneratedProtocolMessageType('QueueMissionScanRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONSCANREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionScanRequest)
  })
_sym_db.RegisterMessage(QueueMissionScanRequest)

QueueMissionScanResponse = _reflection.GeneratedProtocolMessageType('QueueMissionScanResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONSCANRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionScanResponse)
  })
_sym_db.RegisterMessage(QueueMissionScanResponse)

ListMissionScansRequest = _reflection.GeneratedProtocolMessageType('ListMissionScansRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSCANSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionScansRequest)
  })
_sym_db.RegisterMessage(ListMissionScansRequest)

ListMissionScansResponse = _reflection.GeneratedProtocolMessageType('ListMissionScansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSCANSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionScansResponse)
  })
_sym_db.RegisterMessage(ListMissionScansResponse)



_WORKFLOWAPI = _descriptor.ServiceDescriptor(
  name='WorkflowApi',
  full_name='WorkflowApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=721,
  serialized_end=941,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateWorkflow',
    full_name='WorkflowApi.FindOrCreateWorkflow',
    index=0,
    containing_service=None,
    input_type=_WORKFLOWREQUEST,
    output_type=_WORKFLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueueMissionScan',
    full_name='WorkflowApi.QueueMissionScan',
    index=1,
    containing_service=None,
    input_type=_QUEUEMISSIONSCANREQUEST,
    output_type=_QUEUEMISSIONSCANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissionScans',
    full_name='WorkflowApi.ListMissionScans',
    index=2,
    containing_service=None,
    input_type=_LISTMISSIONSCANSREQUEST,
    output_type=_LISTMISSIONSCANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWAPI)

DESCRIPTOR.services_by_name['WorkflowApi'] = _WORKFLOWAPI

# @@protoc_insertion_point(module_scope)
